a client library for the bitcoin exchange OCX
---

# Install
```
pip install ocx_client
```

# Usage
- Rest API Client: https://github.com/ocxapi/ocx-openapi-ruby-client/blob/master/client_sample.py
- Streaming API Client: https://github.com/ocxapi/ocx-openapi-ruby-client/blob/master/streaming_client_sample.py

# Licence
LGPL
